#!/usr/bin/env node

// Imports
var LineStream = require('linestream'),
    argv = require('optimist').argv;

// Print only parts where something matches
function checkAndPrintData(data) {
    // De-serialize base64 - doesn't take all hits, but close enough for our immediate uses.
    data = data.replace(/(\w+):: (.{0,1024})/, function (str, key, base64) {
        return key + ": " + new Buffer(base64, 'base64').toString();
    }, "g");

    // Check if the value we're looking for is there
    if (data.indexOf(argv._[0]) !== -1) {
        console.log(data);
    }
}

// Read stdin line-by-line
var lines = new LineStream(process.stdin);

// Collect the data
var collectedData = "";
lines.on('data', function (data) {
    if (data === "\n") {
        checkAndPrintData(collectedData);
        collectedData = "";
    } else {
        // Stitch together long lines.
        if (data[0] === " ") {
            collectedData = collectedData.substr(0, collectedData.length - 1) + data.substr(1, data.length);
        } else {
            collectedData += data;
        }
    }
});

lines.on('end', function () {
    checkAndPrintData(collectedData);
});

// Start stdin (pause()'d by default)
process.stdin.setEncoding('utf-8');
process.stdin.resume();
